Configuration Options
=====================

The configuration for flaat is handled by a set of calls to the flaat
class, described below.


* :doc:`Example Code </configuration/sample-flask>`: Code with sample config
  statements is given with inline documentation, and in the example-flask.py.
* :doc:`Example Code </configuration/sample-aio>`: Code with sample config
  statements is given with inline documentation, and in the example-aio.py.

